#[repr(transparent)]pub struct Reg2(pub u32);Expand description
DCDC Register 2
Tuple Fields
0: u32Implementations
Sourceimpl Reg2
impl Reg2
Sourcepub const fn loopctrl_dc_ff(&self) -> u8
pub const fn loopctrl_dc_ff(&self) -> u8
Two’s complement feed forward step in duty cycle in the switching DC-DC converter
Sourcepub const fn set_loopctrl_dc_ff(&mut self, val: u8)
pub const fn set_loopctrl_dc_ff(&mut self, val: u8)
Two’s complement feed forward step in duty cycle in the switching DC-DC converter
Sourcepub const fn loopctrl_en_rcscale(&self) -> u8
pub const fn loopctrl_en_rcscale(&self) -> u8
Enable RC Scale
Sourcepub const fn set_loopctrl_en_rcscale(&mut self, val: u8)
pub const fn set_loopctrl_en_rcscale(&mut self, val: u8)
Enable RC Scale
Sourcepub const fn loopctrl_rcscale_thrsh(&self) -> bool
pub const fn loopctrl_rcscale_thrsh(&self) -> bool
Increase the threshold detection for RC scale circuit.
Sourcepub const fn set_loopctrl_rcscale_thrsh(&mut self, val: bool)
pub const fn set_loopctrl_rcscale_thrsh(&mut self, val: bool)
Increase the threshold detection for RC scale circuit.
Sourcepub const fn loopctrl_hyst_sign(&self) -> bool
pub const fn loopctrl_hyst_sign(&self) -> bool
Invert the sign of the hysteresis in DC-DC analog comparators.
Sourcepub const fn set_loopctrl_hyst_sign(&mut self, val: bool)
pub const fn set_loopctrl_hyst_sign(&mut self, val: bool)
Invert the sign of the hysteresis in DC-DC analog comparators.
Sourcepub const fn disable_pulse_skip(&self) -> DisablePulseSkip
pub const fn disable_pulse_skip(&self) -> DisablePulseSkip
Disable Pulse Skip
Sourcepub const fn set_disable_pulse_skip(&mut self, val: DisablePulseSkip)
pub const fn set_disable_pulse_skip(&mut self, val: DisablePulseSkip)
Disable Pulse Skip
Sourcepub const fn dcm_set_ctrl(&self) -> bool
pub const fn dcm_set_ctrl(&self) -> bool
DCM Set Control
Sourcepub const fn set_dcm_set_ctrl(&mut self, val: bool)
pub const fn set_dcm_set_ctrl(&mut self, val: bool)
DCM Set Control